@@ -82,6 +82,19 @@ DEPEND_BY_ENV = 2
 DEPEND_FULLY = 3
 
 
+# Valid systems/environments mini-language
+_N = r'(\w[-.\w]*)'         # name
+_NW = rf'(\*|{_N})'         # name or wildcard
+_F = rf'([+-]{_N})'         # feature
+_OP = r'([=<>]|!=|>=|<=)'   # relational operator (unused for the moment)
+_KV = rf'(%{_N}=\S+)'       # key/value pair
+_FKV = rf'({_F}|{_KV})'     # feature | key/value pair
+_VALID_ENV_SYNTAX = rf'^({_NW}|{_FKV}(\s+{_FKV})*)$'
+
+_S = rf'({_NW}(:{_NW})?)'   # system/partition
+_VALID_SYS_SYNTAX = rf'^({_S}|{_FKV}(\s+{_FKV})*)$'
+
+
 _PIPELINE_STAGES = (
     '__init__',
     'setup',
@@ -215,61 +228,121 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: .. warning::
     #:
-    #:    Setting the name of a test is deprecated and will be disabled in the
-    #:    future. If you were setting the name of a test to circumvent the old
-    #:    long parameterized test names in order to reference them in
-    #:    dependency chains, please refer to :ref:`param_deps` for more details on how
-    #:    to achieve this.
+    #:   Setting the name of a test is deprecated and will be disabled in the
+    #:   future. If you were setting the name of a test to circumvent the old
+    #:   long parameterized test names in order to reference them in
+    #:   dependency chains, please refer to :ref:`param_deps` for more details
+    #:   on how to achieve this.
     #:
     #: .. versionchanged:: 3.10.0
     #:    Setting the :attr:`name` attribute is deprecated.
     #:
-    name = deprecate(variable(typ.Str[r'[^\/]+'], attr_name='_rfm_unique_name'),
+    name = deprecate(variable(typ.Str[r'[^\/]+'],
+                              attr_name='_rfm_unique_name', loggable=True),
                      "setting the 'name' attribute is deprecated and "
                      "will be disabled in the future", DEPRECATE_WR)
 
-    #: List of programming environments supported by this test.
+    #: List of environments or environment features or environment properties
+    #: required by this test.
     #:
-    #: If ``*`` is in the list then all programming environments are supported
-    #: by this test.
+    #: The syntax of this attribute is exactly the same as of the
+    #: :attr:`valid_systems` except that the ``a:b`` entries are invalid.
     #:
     #: :type: :class:`List[str]`
     #: :default: ``required``
     #:
-    #: .. note::
-    #:     .. versionchanged:: 2.12
-    #:        Programming environments can now be specified using wildcards.
+    #: .. seealso::
+    #:    - `Environment features
+    #:      <config_reference.html#environments-.features>`__
+    #:    - `Environment extras
+    #:      <config_reference.html#environments-.extras>`__
     #:
-    #:     .. versionchanged:: 2.17
-    #:        Support for wildcards is dropped.
+    #: .. versionchanged:: 2.12
+    #:    Programming environments can now be specified using wildcards.
     #:
-    #:     .. versionchanged:: 3.3
-    #:        Default value changed from ``[]`` to ``None``.
+    #: .. versionchanged:: 2.17
+    #:    Support for wildcards is dropped.
     #:
-    #:     .. versionchanged:: 3.6
-    #:        Default value changed from ``None`` to ``required``.
-    valid_prog_environs = variable(typ.List[str])
+    #: .. versionchanged:: 3.3
+    #:    Default value changed from ``[]`` to ``None``.
+    #:
+    #: .. versionchanged:: 3.6
+    #:    Default value changed from ``None`` to ``required``.
+    #:
+    #: .. versionchanged:: 3.11.0
+    #:    Extend syntax to support features and key/value pairs.
+    valid_prog_environs = variable(typ.List[typ.Str[_VALID_ENV_SYNTAX]],
+                                   loggable=True)
 
-    #: List of systems supported by this test.
-    #: The general syntax for systems is ``<sysname>[:<partname>]``.
-    #: Both <sysname> and <partname> accept the value ``*`` to mean any value.
-    #: ``*`` is an alias of ``*:*``
+    #: List of systems or system features or system properties required by this
+    #: test.
+    #:
+    #: Each entry in this list is a requirement and can have one of the
+    #: following forms:
+    #:
+    #: - ``sysname``: The test is valid for system named ``sysname``.
+    #: - ``sysname:partname``: The test is valid for the partition ``partname``
+    #:   of system ``sysname``.
+    #: - ``*``: The test is valid for any system.
+    #: - ``*:partname``: The test is valid for any partition named ``partname``
+    #:   in any system.
+    #: - ``+feat``: The test is valid for all partitions that define feature
+    #:   ``feat`` as a feature.
+    #: - ``-feat``: The test is valid for all partitions that do not define
+    #:   feature ``feat`` as a feature.
+    #: - ``%key=val``: The test is valid for all partitions that define the
+    #:   extra property ``key`` with the value ``val``.
+    #:
+    #: Multiple features and key/value pairs can be included in a single entry
+    #: of the :attr:`valid_systems` list, in which case an AND operation on
+    #: these constraints is implied. For example, the test defining the
+    #: following will be valid for all systems that have define both ``feat1``
+    #: and ``feat2`` and set ``foo=1``
+    #:
+    #: .. code-block:: python
+    #:
+    #:    valid_systems = ['+feat1 +feat2 %foo=1']
+    #:
+    #: For key/value pairs comparisons, ReFrame will automatically convert the
+    #: value in the key/value spec to the type of the value of the
+    #: corresponding entry in the partitions ``extras`` property. In the above
+    #: example, if the type of ``foo`` property is integer, ``1`` will be
+    #: converted to an integer value. If a conversion to the target type is not
+    #: possible, then the requested key/value pair is not matched.
+    #:
+    #: Multiple entries in the :attr:`valid_systems` list are implicitly ORed,
+    #: such that the following example implies that the test is valid for
+    #: either ``sys1`` or for any other system that does not define ``feat``.
+    #:
+    #: .. code-block:: python
+    #:
+    #:    valid_systems = ['sys1', '-feat']
     #:
     #: :type: :class:`List[str]`
     #: :default: ``None``
     #:
-    #:     .. versionchanged:: 3.3
-    #:        Default value changed from ``[]`` to ``None``.
+    #: .. seealso::
+    #:    - `System partition features
+    #:      <config_reference.html#systems-.partitions-.features>`__
+    #:    - `System partition extras
+    #:      <config_reference.html#systems-.partitions-.extras>`__
     #:
-    #:     .. versionchanged:: 3.6
-    #:        Default value changed from ``None`` to ``required``.
-    valid_systems = variable(typ.List[str])
+    #: .. versionchanged:: 3.3
+    #:    Default value changed from ``[]`` to ``None``.
+    #:
+    #: .. versionchanged:: 3.6
+    #:    Default value changed from ``None`` to ``required``.
+    #:
+    #:  .. versionchanged:: 3.11.0
+    #:     Extend syntax to support features and key/value pairs.
+    valid_systems = variable(typ.List[typ.Str[_VALID_SYS_SYNTAX]],
+                             loggable=True)
 
     #: A detailed description of the test.
     #:
     #: :type: :class:`str`
     #: :default: ``self.display_name``
-    descr = variable(str)
+    descr = variable(str, loggable=True)
 
     #: The path to the source file or source directory of the test.
     #:
@@ -287,7 +360,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`str`
     #: :default: ``''``
-    sourcepath = variable(str, value='')
+    sourcepath = variable(str, value='', loggable=True)
 
     #: The directory containing the test's resources.
     #:
@@ -317,7 +390,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:     .. versionchanged:: 3.0
     #:        Default value is now conditionally set to either ``'src'`` or
     #:        :class:`None`.
-    sourcesdir = variable(str, type(None), value='src')
+    sourcesdir = variable(str, type(None), value='src', loggable=True)
 
     #: .. versionadded:: 2.14
     #:
@@ -346,7 +419,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    prebuild_cmds = variable(typ.List[str], value=[])
+    prebuild_cmds = variable(typ.List[str], value=[], loggable=True)
 
     #: .. versionadded:: 3.0
     #:
@@ -358,7 +431,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    postbuild_cmds = variable(typ.List[str], value=[])
+    postbuild_cmds = variable(typ.List[str], value=[], loggable=True)
 
     #: The name of the executable to be launched during the run phase.
     #:
@@ -373,13 +446,13 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: .. versionchanged:: 3.7.3
     #:    Default value changed from ``os.path.join('.', self.unique_name)`` to
     #:    :class:`required`.
-    executable = variable(str)
+    executable = variable(str, loggable=True)
 
     #: List of options to be passed to the :attr:`executable`.
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    executable_opts = variable(typ.List[str], value=[])
+    executable_opts = variable(typ.List[str], value=[], loggable=True)
 
     #: .. versionadded:: 2.20
     #:
@@ -416,7 +489,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    prerun_cmds = variable(typ.List[str], value=[])
+    prerun_cmds = variable(typ.List[str], value=[], loggable=True)
 
     #: .. versionadded:: 3.0
     #:
@@ -427,7 +500,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    postrun_cmds = variable(typ.List[str], value=[])
+    postrun_cmds = variable(typ.List[str], value=[], loggable=True)
 
     #: List of files to be kept after the test finishes.
     #:
@@ -447,7 +520,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: .. versionchanged:: 3.3
     #:    This field accepts now also file glob patterns.
     #:
-    keep_files = variable(typ.List[str], value=[])
+    keep_files = variable(typ.List[str], value=[], loggable=True)
 
     #: List of files or directories (relative to the :attr:`sourcesdir`) that
     #: will be symlinked in the stage directory and not copied.
@@ -457,7 +530,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    readonly_files = variable(typ.List[str], value=[])
+    readonly_files = variable(typ.List[str], value=[], loggable=True)
 
     #: Set of tags associated with this test.
     #:
@@ -465,7 +538,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`Set[str]`
     #: :default: an empty set
-    tags = variable(typ.Set[str], value=set())
+    tags = variable(typ.Set[str], value=set(), loggable=True)
 
     #: List of people responsible for this test.
     #:
@@ -473,7 +546,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`List[str]`
     #: :default: ``[]``
-    maintainers = variable(typ.List[str], value=[])
+    maintainers = variable(typ.List[str], value=[], loggable=True)
 
     #: Mark this test as a strict performance test.
     #:
@@ -483,7 +556,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: boolean
     #: :default: :class:`True`
-    strict_check = variable(typ.Bool, value=True)
+    strict_check = variable(typ.Bool, value=True, loggable=True)
 
     #: Number of tasks required by this test.
     #:
@@ -509,7 +582,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: .. |--flex-alloc-nodes| replace:: :attr:`--flex-alloc-nodes`
     #: .. _--flex-alloc-nodes: manpage.html#cmdoption-flex-alloc-nodes
-    num_tasks = variable(int, value=1)
+    num_tasks = variable(int, value=1, loggable=True)
 
     #: Number of tasks per node required by this test.
     #:
@@ -517,7 +590,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: integral or :class:`None`
     #: :default: :class:`None`
-    num_tasks_per_node = variable(int, type(None), value=None)
+    num_tasks_per_node = variable(int, type(None), value=None, loggable=True)
 
     #: Number of GPUs per node required by this test.
     #: This attribute is translated internally to the ``_rfm_gpu`` resource.
@@ -526,7 +599,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: integral
     #: :default: ``0``
-    num_gpus_per_node = variable(int, value=0)
+    num_gpus_per_node = variable(int, value=0, loggable=True)
 
     #: Number of CPUs per task required by this test.
     #:
@@ -534,7 +607,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: integral or :class:`None`
     #: :default: :class:`None`
-    num_cpus_per_task = variable(int, type(None), value=None)
+    num_cpus_per_task = variable(int, type(None), value=None, loggable=True)
 
     #: Number of tasks per core required by this test.
     #:
@@ -542,7 +615,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: integral or :class:`None`
     #: :default: :class:`None`
-    num_tasks_per_core = variable(int, type(None), value=None)
+    num_tasks_per_core = variable(int, type(None), value=None, loggable=True)
 
     #: Number of tasks per socket required by this test.
     #:
@@ -550,7 +623,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: integral or :class:`None`
     #: :default: :class:`None`
-    num_tasks_per_socket = variable(int, type(None), value=None)
+    num_tasks_per_socket = variable(int, type(None), value=None, loggable=True)
 
     #: Specify whether this tests needs simultaneous multithreading enabled.
     #:
@@ -558,7 +631,8 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: boolean or :class:`None`
     #: :default: :class:`None`
-    use_multithreading = variable(typ.Bool, type(None), value=None)
+    use_multithreading = variable(
+        typ.Bool, type(None), value=None, loggable=True)
 
     #: .. versionadded:: 3.0
     #:
@@ -569,19 +643,20 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: :type: :class:`str` or :class:`datetime.timedelta`
     #: :default: :class:`None`
     max_pending_time = variable(
-        type(None), field=fields.TimerField, value=None)
+        type(None), field=fields.TimerField, value=None, loggable=True
+    )
 
     #: Specify whether this test needs exclusive access to nodes.
     #:
     #: :type: boolean
     #: :default: :class:`False`
-    exclusive_access = variable(typ.Bool, value=False)
+    exclusive_access = variable(typ.Bool, value=False, loggable=True)
 
     #: Always execute this test locally.
     #:
     #: :type: boolean
     #: :default: :class:`False`
-    local = variable(typ.Bool, value=False)
+    local = variable(typ.Bool, value=False, loggable=True)
 
     #: The set of reference values for this test.
     #:
@@ -606,6 +681,25 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:        }
     #:    }
     #:
+    #: To better understand how to set the performance reference tuple, here
+    #: are some examples with both positive and negative reference values:
+    #:
+    #:   ============================== ============  ==========  ===========
+    #:   **Performance Tuple**          **Expected**  **Lowest**  **Highest**
+    #:   ``(100, -0.01, 0.02, 'MB/s')`` 100 MB/s      99 MB/s     102 MB/s
+    #:   ``(100, -0.01, None, 'MB/s')`` 100 MB/s      99 MB/s     inf MB/s
+    #:   ``(100, None, 0.02, 'MB/s')``  100 MB/s      -inf MB/s   102 MB/s
+    #:   ``(-100, -0.01, 0.02, 'C')``     -100 C        -101 C      -98 C
+    #:   ``(-100, -0.01, None, 'C')``     -100 C        -101 C      inf C
+    #:   ``(-100, None, 0.02, 'C')``      -100 C        -inf C      -98 C
+    #:   ============================== ============  ==========  ===========
+    #:
+    #: During the performance stage of the pipeline, the reference tuple
+    #: elements, except the unit, are passed to the
+    #: :func:`~reframe.utility.sanity.assert_reference` function along with the
+    #: obtained performance value in order to actually assess whether the test
+    #: passes the performance check or not.
+    #:
     #: :type: A scoped dictionary with system names as scopes or :class:`None`
     #: :default: ``{}``
     #:
@@ -704,7 +798,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: :type: :class:`List[str]`
     #: :default: ``[]``
     modules = variable(typ.List[str], typ.List[typ.Dict[str, object]],
-                       value=[])
+                       value=[], loggable=True)
 
     #: Environment variables to be set before running this test.
     #:
@@ -712,7 +806,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #: :type: :class:`Dict[str, str]`
     #: :default: ``{}``
-    variables = variable(typ.Dict[str, str], value={})
+    variables = variable(typ.Dict[str, str], value={}, loggable=True)
 
     #: Time limit for this test.
     #:
@@ -743,7 +837,8 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:
     #:    .. |time_limit| replace:: :attr:`time_limit`
     #:    .. _time_limit: #.systems[].partitions[].time_limit
-    time_limit = variable(type(None), field=fields.TimerField, value=None)
+    time_limit = variable(type(None), field=fields.TimerField,
+                          value=None, loggable=True)
 
     #: .. versionadded:: 3.5.1
     #:
@@ -754,7 +849,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: :type: :class:`str` or :class:`float` or :class:`int`
     #: :default: :class:`None`
     build_time_limit = variable(type(None), field=fields.TimerField,
-                                value=None)
+                                value=None, loggable=True)
 
     #: .. versionadded:: 2.8
     #:
@@ -826,7 +921,8 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #:    .. versionchanged:: 2.9
     #:       A new more powerful syntax was introduced
     #:       that allows also custom job script directive prefixes.
-    extra_resources = variable(typ.Dict[str, typ.Dict[str, object]], value={})
+    extra_resources = variable(typ.Dict[str, typ.Dict[str, object]],
+                               value={}, loggable=True)
 
     #: .. versionadded:: 3.3
     #:
@@ -841,7 +937,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     #: appropriate sanity check.
     #:
     #: :type: boolean : :default: :class:`True`
-    build_locally = variable(typ.Bool, value=True)
+    build_locally = variable(typ.Bool, value=True, loggable=True)
 
     def __new__(cls, *args, **kwargs):
         obj = super().__new__(cls)
@@ -976,7 +1072,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         '''Process and validate the pipeline hooks.'''
 
         _pipeline_hooks = {}
-        for stage, hooks in cls.pipeline_hooks().items():
+        for stage, hks in cls.pipeline_hooks().items():
             # Pop the stage pre_/post_ prefix
             stage_name = stage.split('_', maxsplit=1)[1]
 
@@ -996,7 +1092,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
             elif stage == 'post_run':
                 stage = 'post_run_wait'
 
-            _pipeline_hooks[stage] = hooks
+            _pipeline_hooks[stage] = hks
 
         return _pipeline_hooks
 
@@ -1023,11 +1119,6 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
             raise AttributeError(
                 f'required variable {name!r} has not been set'
             ) from None
-        elif name in self._rfm_fixture_space:
-            raise AttributeError(
-                f'fixture {name!r} has not yet been resolved: '
-                f'fixtures are resolved during the setup stage'
-            )
         else:
             raise AttributeError(
                 f'{type(self).__qualname__!r} object has no attribute {name!r}'
@@ -1035,6 +1126,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
 
     # Export read-only views to interesting fields
 
+    @loggable
     @property
     def unique_name(self):
         '''The unique name of this test.
@@ -1045,6 +1137,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         '''
         return self._rfm_unique_name
 
+    @loggable
     @property
     def display_name(self):
         '''A human-readable version of the name this test.
@@ -1186,6 +1279,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         if not var_space[name].is_defined():
             setattr(self, name, value)
 
+    @loggable
     @property
     def perfvalues(self):
         return util.MappingView(self._perfvalues)
@@ -1208,6 +1302,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         '''
         return logging.getlogger()
 
+    @loggable
     @property
     def prefix(self):
         '''The prefix directory of the test.
@@ -1216,6 +1311,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         '''
         return self._prefix
 
+    @loggable
     @property
     def stagedir(self):
         '''The stage directory of the test.
@@ -1226,6 +1322,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         '''
         return self._stagedir
 
+    @loggable
     @property
     def outputdir(self):
         '''The output directory of the test.
@@ -1282,6 +1379,49 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
     def build_stderr(self):
         return self.build_job.stderr if self.build_job else None
 
+    # Various properties useful only for logging
+
+    @loggable_as('system')
+    @property
+    def _system_name(self):
+        return self.current_system.name
+
+    @loggable_as('partition')
+    @property
+    def _partition_name(self):
+        if self.current_partition:
+            return self.current_partition.name
+
+    @loggable_as('environ')
+    @property
+    def _environ_name(self):
+        if self.current_environ:
+            return self.current_environ.name
+
+    @loggable_as('jobid')
+    @property
+    def _jobid(self):
+        if self.job:
+            return self.job.jobid
+
+    @loggable_as('job_completion_time_unix')
+    @property
+    def _job_completion_time(self):
+        if self.job:
+            return self.job.completion_time
+
+    @loggable_as('job_exitcode')
+    @property
+    def _job_exitcode(self):
+        if self.job:
+            return self.job.exitcode
+
+    @loggable_as('job_nodelist')
+    @property
+    def _job_nodelist(self):
+        if self.job:
+            return self.job.nodelist
+
     def info(self):
         '''Provide live information for this test.
 
@@ -1313,23 +1453,6 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
 
         return ret
 
-    def supports_system(self, name):
-        if name.find(':') != -1:
-            system, partition = name.split(':')
-        else:
-            system, partition = self.current_system.name, name
-
-        valid_matches = ['*', '*:*', system, f'{system}:*',
-                         f'*:{partition}', f'{system}:{partition}']
-
-        return any(n in self.valid_systems for n in valid_matches)
-
-    def supports_environ(self, env_name):
-        if '*' in self.valid_prog_environs:
-            return True
-
-        return env_name in self.valid_prog_environs
-
     def is_local(self):
         '''Check if the test will execute locally.
 
@@ -1460,9 +1583,7 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
                           launcher,
                           name=name,
                           workdir=self._stagedir,
-                          max_pending_time=self.max_pending_time,
                           sched_access=self._current_partition.access,
-                          sched_exclusive_access=self.exclusive_access,
                           **job_opts)
 
     def _setup_perf_logging(self):
@@ -1714,6 +1835,8 @@ class RegressionTest(RegressionMixin, jsonext.JSONSerializable):
         self.job.time_limit = (self.time_limit or rt.runtime().get_option(
             f'systems/0/partitions/@{self.current_partition.name}/time_limit')
         )
+        self.job.max_pending_time = self.max_pending_time
+        self.job.exclusive_access = self.exclusive_access
         exec_cmd = [self.job.launcher.run_command(self.job),
                     self.executable, *self.executable_opts]
 
